﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Data;
using System.Windows;
using KB9964_XamDataGrid_AddingRowSeparator_WpfApp1.Model;

namespace KB9964_XamDataGrid_AddingRowSeparator_WpfApp1;

internal class DataRecordToSeparatorConverter : IMultiValueConverter
{
    // このコンバーター内のロジックはご自由に実装してください。

    public object Convert(object[] values, Type targetType, object parameter, CultureInfo culture)
    {
        // 期待通りの引数が渡されてこなかった場合は何もしない
        if (values == null
            || values.Length != 2
            || values[0].GetType() != typeof(DataRecord)
            || values[1].GetType() != typeof(ViewableRecordCollection))
        {
            return Binding.DoNothing;
        }

        // このIMultiValueConverterが呼び出された行のDataRecord、
        // DataPresenterの表示順のDataRecordのコレクション、
        // 次の行のDataRecord
        // を取得する。
        // 次の行のDataRecordが取得できなかったら何もしない。
        var dataRecord = (DataRecord)values[0];
        var dataRecords = ((ViewableRecordCollection)values[1]).Where(r => r.IsDataRecord).Cast<DataRecord>().ToList();
        var nextDataRecord = dataRecords.FirstOrDefault(r => r.Index == dataRecords.IndexOf(dataRecord) + 1);
        if (nextDataRecord == null)
        {
            return Binding.DoNothing;
        }

        // この行と次の行のStudentデータを取得する。
        var student = dataRecord.DataItem as Student;
        var nextStudent = nextDataRecord.DataItem as Student;
        // Studentデータが取得できなかったら何もしない。
        if (student == null || nextStudent == null)
        {
            return Binding.DoNothing;
        }

        // 次の学生と学部が異なる場合は、現在の行の下に線を引く
        if (student.Faculty != nextStudent.Faculty)
        {
            return new Thickness(0, 0, 0, 1);
        }

        return new Thickness(0, 0, 0, 0);
    }

    public object[] ConvertBack(object value, Type[] targetTypes, object parameter, CultureInfo culture)
    {
        throw new NotImplementedException();
    }
}
